@@ -1,23 +1,24 @@
 """Manage Client auth flow."""
 
 import json
+import logging
 import time
 from copy import deepcopy
 from importlib import resources
-from typing import Any
+from typing import Any, Dict, Optional, Tuple
 
 import jsonschema  # type: ignore[import]
 from jsonschema import ValidationError
 
 from multiauth import static
-from multiauth.config import PY_MULTIAUTH_LOGGER as logger
+from multiauth.entities.errors import InvalidConfigurationError
+from multiauth.entities.http import HTTPMethod
+from multiauth.entities.interfaces import IMultiAuth
+from multiauth.entities.main import AuthTech, Token
 from multiauth.handlers import auth_handler, reauth_handler
 from multiauth.manager import User, UserManager
 from multiauth.providers.aws import aws_signature
-from multiauth.types.errors import InvalidConfigurationError
-from multiauth.types.http import HTTPMethod
-from multiauth.types.interfaces import IMultiAuth
-from multiauth.types.main import AuthTech, Token
+from multiauth.utils import setup_logger
 
 
 class MultiAuth(IMultiAuth):
@@ -26,49 +27,55 @@ class MultiAuth(IMultiAuth):
 
     def __init__(
         self,
-        auths: dict,
-        users: dict,
+        auths: Dict,
+        users: Dict,
+        logger: Optional[logging.Logger] = None,
     ) -> None:
         """Initialize the Auth manager."""
 
+        self._logger = logger or setup_logger()
+
         self.validate(auths, users)
 
         self._manager: UserManager = UserManager(self.serialize_users(auths, users))
-        self._headers: dict[str, dict] = {}
+        self._headers: Dict[str, Dict] = {}
         self._auths = auths
 
     @property
-    def headers(self) -> dict[str, dict]:
+    def headers(self) -> Dict[str, Dict]:
         """Fetch all headers of the internal manager."""
 
         return self._headers
 
     @property
-    def users(self) -> dict[str, User]:
+    def users(self) -> Dict[str, User]:
         """Fetch all users of the internal manager."""
 
         return self._manager.users
 
     @property
-    def schemas(self) -> dict:
+    def schemas(self) -> Dict:
         """Fetch internal schemas."""
 
         return self._auths
 
     @staticmethod
-    def validate(auths: dict, users: dict) -> None:
+    def validate(
+        auths: Dict,
+        users: Dict,
+    ) -> None:
         """Validate the auth schema and users with json schema."""
 
         # Load the json schema from static
         with resources.open_text(static, 'auth_schema.json') as f:
             json_schema = json.load(f)
 
-        auth_tech_link: dict[str, str] = {}
+        auth_tech_link: Dict[str, str] = {}
         s_users = ', '.join(auth_tech_link.keys())
 
         for auth_name, auth in auths.items():
-            if auth is None or not isinstance(auth, dict):
-                raise InvalidConfigurationError(message='auth is None or is not a dict', path=f'$.auth.{auth_name}')
+            if auth is None or not isinstance(auth, Dict):
+                raise InvalidConfigurationError(message='auth is None or is not a Dict', path=f'$.auth.{auth_name}')
             if 'tech' not in auth:
                 raise InvalidConfigurationError(message='\'tech\' is a required property', path=f'$.auth.{auth_name}')
             if auth['tech'] not in json_schema:
@@ -80,8 +87,8 @@ class MultiAuth(IMultiAuth):
                 raise InvalidConfigurationError(message=e.message, path=f'$.auth.{auth_name}' + str(e.json_path)[2:]) from e
 
         for username, user in users.items():
-            if user is None or not isinstance(user, dict):
-                raise InvalidConfigurationError(message='user is None or is not a dict', path=f'$.users.{username}')
+            if user is None or not isinstance(user, Dict):
+                raise InvalidConfigurationError(message='user is None or is not a Dict', path=f'$.users.{username}')
             if 'auth' not in user:
                 raise InvalidConfigurationError(message='\'auth\' is a required property inside a user', path=f'$.users.{username}')
             if user['auth'] not in auth_tech_link:
@@ -94,14 +101,19 @@ class MultiAuth(IMultiAuth):
                 raise InvalidConfigurationError(message=e.message, path=f'$.users.{username}' + e.json_path[2:]) from e
 
     @staticmethod
-    def serialize_users(auths: dict, users: dict) -> dict[str, User]:
+    def serialize_users(
+        auths: Dict,
+        users: Dict,
+    ) -> Dict[str, User]:
         """Serialize raw user to valid config format."""
 
+        users = deepcopy(users)
+
         for user, user_info in users.items():
 
             schema = auths[user_info['auth']]
 
-            _user_credientials: dict[str, Any] = deepcopy(user_info)
+            _user_credientials: Dict[str, Any] = deepcopy(user_info)
             del _user_credientials['auth']
 
             _user: User = User({
@@ -119,9 +131,9 @@ class MultiAuth(IMultiAuth):
         url: str,
         username: str,
         method: HTTPMethod,
-        headers: dict[str, str],
+        headers: Dict[str, str],
         formatted_payload: Any,
-    ) -> dict[str, str]:
+    ) -> Dict[str, str]:
         """Sign a payload before sending it.
 
         This is a mandatory for AWS Signature.
@@ -144,7 +156,7 @@ class MultiAuth(IMultiAuth):
     def authenticate(
         self,
         username: str,
-    ) -> tuple[dict[str, str], str]:
+    ) -> Tuple[Dict[str, str], str]:
         """Authenticate the client using the current user."""
 
         # Reset the user's headers
@@ -153,11 +165,11 @@ class MultiAuth(IMultiAuth):
         user_info: User = self._manager.users[username]
 
         # Call the auth handler
-        logger.info(f'Authenticating user: {username}')
+        self._logger.info(f'Authenticating user: {username}')
         auth_response = auth_handler(self._auths, user_info)
-        if auth_response and isinstance(auth_response, dict):
+        if auth_response and isinstance(auth_response, Dict):
             self._headers[username] = auth_response['headers']
-            logger.info(f'Authentication successful for {username}')
+            self._logger.info(f'Authentication successful for {username}')
 
         # In case we provided custom headers, we need to merge them with the ones we got from auth_handler
         if user_info.headers:
@@ -165,12 +177,12 @@ class MultiAuth(IMultiAuth):
 
         return self._headers[username], username
 
-    def authenticate_users(self) -> dict[str, Token | None]:
+    def authenticate_users(self) -> Dict[str, Optional[Token]]:
         """Authenticate all the users."""
 
-        tokens: dict[str, Token | None] = {}
+        tokens: Dict[str, Optional[Token]] = {}
         for user, user_info in self._manager.users.items():
-            logger.info(f'Authenticating users : {user}')
+            self._logger.info(f'Authenticating users : {user}')
 
             if user_info.auth_schema:
                 self.authenticate(user)
@@ -182,9 +194,9 @@ class MultiAuth(IMultiAuth):
     def reauthenticate(
         self,
         username: str,
-        headers: dict[str, str] | None = None,
+        headers: Optional[Dict[str, str]] = None,
         no_auth: bool = False,
-    ) -> tuple[dict[str, str], str | None]:
+    ) -> Tuple[Dict[str, str], Optional[str]]:
         """Reauthentication of the user in case of token expiry."""
 
         user_info = self._manager.users[username]
@@ -194,7 +206,7 @@ class MultiAuth(IMultiAuth):
         # If there is no expiry date, no reauthentication is necessary
         # If the expiry date is more then the current time, no reauthentication is necessary
         if expiry_time and expiry_time < time.time():
-            logger.info('Token is expired')
+            self._logger.info('Token is expired')
 
             user_info.expired_token = user_info.token
 
@@ -213,9 +225,9 @@ class MultiAuth(IMultiAuth):
                     user_info,
                 )
 
-            if auth_response and isinstance(auth_response, dict):
+            if auth_response and isinstance(auth_response, Dict):
                 self._headers[username] = auth_response['headers']
-                logger.info('Reauthentication Successful')
+                self._logger.info('Reauthentication Successful')
 
         headers = headers or {}
         if not no_auth:
