@@ -1,20 +1,23 @@
 """User manager."""
 
 import time
-from typing import Any
+from typing import Any, Dict, Optional, Tuple
 
+from multiauth.entities.errors import AuthenticationError, ExpiredTokenError
+from multiauth.entities.interfaces import IUser
+from multiauth.entities.main import AuthTech, AuthType, JWTToken, Token
 from multiauth.helpers import jwt_token_analyzer
-from multiauth.types.errors import AuthenticationError, ExpiredTokenError
-from multiauth.types.interfaces import IBase
-from multiauth.types.main import AuthTech, AuthType, JWTToken, Token
 
 
 # pylint: disable=too-many-instance-attributes
-class User(IBase):
+class User(IUser):
 
     """User entity."""
 
-    def __init__(self, kwargs: dict[str, Any] | None = None) -> None:
+    def __init__(
+        self,
+        kwargs: Optional[Dict[str, Any]] = None,
+    ) -> None:
         """Init user."""
 
         self.reset()
@@ -37,25 +40,28 @@ class User(IBase):
     def reset(self) -> None:
         """Reset user."""
 
-        self._auth_schema: str | None = None
+        self._auth_schema: Optional[str] = None
         self._auth_tech: AuthTech = AuthTech.NOAUTH
-        self._auth_type: AuthType | None = None
-        self._credentials: dict[str, Any] | None = None
-        self._expired_token: Token | None = None
-        self._expires_in: float | None = None
-        self._headers: dict[str, Any] | None = None
-        self._refresh_token: Token | None = None
-        self._token_info: JWTToken | None = None
-        self._token: Token | None = None
+        self._auth_type: Optional[AuthType] = None
+        self._credentials: Optional[Dict[str, Any]] = None
+        self._expired_token: Optional[Token] = None
+        self._expires_in: Optional[float] = None
+        self._headers: Optional[Dict[str, Any]] = None
+        self._refresh_token: Optional[Token] = None
+        self._token_info: Optional[JWTToken] = None
+        self._token: Optional[Token] = None
 
     @property
-    def auth_schema(self) -> str | None:
+    def auth_schema(self) -> Optional[str]:
         """Get auth schema."""
 
         return self._auth_schema
 
     @auth_schema.setter
-    def auth_schema(self, value: str | None) -> None:
+    def auth_schema(
+        self,
+        value: Optional[str],
+    ) -> None:
         """Set auth schema."""
 
         self._auth_schema = value
@@ -67,102 +73,130 @@ class User(IBase):
         return self._auth_tech
 
     @auth_tech.setter
-    def auth_tech(self, value: AuthTech) -> None:
+    def auth_tech(
+        self,
+        value: AuthTech,
+    ) -> None:
         """Set auth tech."""
 
         self._auth_tech = value
 
     @property
-    def auth_type(self) -> AuthType | None:
+    def auth_type(self) -> Optional[AuthType]:
         """Get the authentication type."""
 
         return self._auth_type
 
     @auth_type.setter
-    def auth_type(self, auth_type: AuthType | None) -> None:
+    def auth_type(
+        self,
+        auth_type: Optional[AuthType],
+    ) -> None:
         """Set the authentication type."""
 
         self._auth_type = auth_type
 
     @property
-    def credentials(self) -> dict[str, Any] | None:
+    def credentials(self) -> Optional[Dict[str, Any]]:
         """Get credentials."""
 
         return self._credentials
 
     @credentials.setter
-    def credentials(self, value: dict[str, Any]) -> None:
+    def credentials(
+        self,
+        value: Dict[str, Any],
+    ) -> None:
         """Set credentials."""
 
         self._credentials = value
 
     @property
-    def expired_token(self) -> Token | None:
+    def expired_token(self) -> Optional[Token]:
         """Get the expired token."""
 
         return self._expired_token
 
     @expired_token.setter
-    def expired_token(self, token: Token | None) -> None:
+    def expired_token(
+        self,
+        token: Optional[Token],
+    ) -> None:
         """Set the expired token."""
 
         self._expired_token = token
 
     @property
-    def expires_in(self) -> float | None:
+    def expires_in(self) -> Optional[float]:
         """Get the expiration time."""
 
         return self._expires_in
 
     @expires_in.setter
-    def expires_in(self, expires_in: float | None) -> None:
+    def expires_in(
+        self,
+        expires_in: Optional[float],
+    ) -> None:
         """Set the expiration time."""
 
         self._expires_in = expires_in
 
     @property
-    def headers(self) -> dict[str, Any] | None:
+    def headers(self) -> Optional[Dict[str, Any]]:
         """Get headers."""
 
         return self._headers
 
     @property
-    def refresh_token(self) -> Token | None:
+    def refresh_token(self) -> Optional[Token]:
         """Get the refresh token."""
 
         return self._refresh_token
 
     @refresh_token.setter
-    def refresh_token(self, token: Token | None) -> None:
+    def refresh_token(
+        self,
+        token: Optional[Token],
+    ) -> None:
         """Set the refresh token."""
 
         self._refresh_token = token
 
     @property
-    def token_info(self) -> JWTToken | None:
+    def token_info(self) -> Optional[JWTToken]:
         """Get the token info."""
 
         return self._token_info
 
     @token_info.setter
-    def token_info(self, token: JWTToken | None) -> None:
+    def token_info(
+        self,
+        token: Optional[JWTToken],
+    ) -> None:
         """Set the token info."""
 
         self._token_info = token
 
     @property
-    def token(self) -> Token | None:
+    def token(self) -> Optional[Token]:
         """Get the token."""
 
         return self._token
 
     @token.setter
-    def token(self, token: Token | None) -> None:
+    def token(
+        self,
+        token: Optional[Token],
+    ) -> None:
         """Set the token."""
 
         self._token = token
 
-    def set_token(self, token: Token | None, expires_in: float | None) -> None:
+    def set_token(
+        self,
+        token: Optional[Token],
+        expires_in: Optional[float],
+    ) -> None:
         """Set token."""
 
         self.token = token
@@ -174,7 +208,7 @@ class User(IBase):
             except AuthenticationError:
                 pass
 
-    def get_credentials(self) -> tuple[str, str]:
+    def get_credentials(self) -> Tuple[str, str]:
         """Get credentials."""
 
         if not self.credentials:
@@ -186,8 +220,8 @@ class User(IBase):
 
         return self.credentials['username'], self.credentials['password']
 
-    def to_dict(self) -> dict[str, Any]:
-        """Get user as dict."""
+    def to_dict(self) -> Dict[str, Any]:
+        """Get user as Dict."""
 
         return {
             'auth_schema': self.auth_schema,
@@ -206,18 +240,18 @@ class UserManager:
 
     """User manager."""
 
-    _users: dict[str, User]
+    _users: Dict[str, User]
 
     def __init__(
         self,
-        users: dict[str, User] | None = None,
+        users: Optional[Dict[str, User]] = None,
     ) -> None:
         """Initialize the User manager."""
 
         if not users:
             users = {}
 
-        self._users: dict[str, User] = users
+        self._users: Dict[str, User] = users
 
     def reset(self) -> None:
         """Reset the user manager."""
@@ -225,7 +259,7 @@ class UserManager:
         self._users = {}
 
     @property
-    def users(self) -> dict[str, User]:
+    def users(self) -> Dict[str, User]:
         """Get all users."""
 
         return self._users
